@@ -106,19 +106,25 @@ def make_fit_imaging_x2_plane_inversion_7x7():
 
 def make_fit_interferometer_x1_plane_7x7():
     return al.FitInterferometer(
-        dataset=make_interferometer_7(), tracer=make_tracer_x1_plane_7x7()
+        dataset=make_interferometer_7(),
+        tracer=make_tracer_x1_plane_7x7(),
+        settings_inversion=aa.SettingsInversion(use_w_tilde=False),
     )
 
 
 def make_fit_interferometer_x2_plane_7x7():
     return al.FitInterferometer(
-        dataset=make_interferometer_7(), tracer=make_tracer_x2_plane_7x7()
+        dataset=make_interferometer_7(),
+        tracer=make_tracer_x2_plane_7x7(),
+        settings_inversion=aa.SettingsInversion(use_w_tilde=False),
     )
 
 
 def make_fit_interferometer_x2_plane_inversion_7x7():
     return al.FitInterferometer(
-        dataset=make_interferometer_7(), tracer=make_tracer_x2_plane_inversion_7x7()
+        dataset=make_interferometer_7(),
+        tracer=make_tracer_x2_plane_inversion_7x7(),
+        settings_inversion=aa.SettingsInversion(use_w_tilde=False),
     )
 
 
